Aloha editable impress.js | presentation tool based on the power of CSS3 transforms and transitions in modern browsers
Author: Bartek Szopka
Description: impress.js is a presentation tool based on the power of CSS3 transforms and transitions in modern browsers and inspired by the idea behind prezi.com. It's using Aloha Editor to make the content inline editable.

Your browser doesn't support the features required by impress.js, so you are presented with a simplified version of this presentation.

For the best experience please use the latest Chrome or Safari browser. Firefox 10 (to be released soon) will also handle it.

Aren't you just bored with all those WYSIWYG editors?

You like impress.js / jmpress.js?

You would love to have an easy way to edit this slides?

Just click and edit!
Aloha Editor - HTML5 inline Editor

The world's most advanced browser HTML5 based WYSIWYG editor lets you experience a whole new way of editing. It's faster than existing technologies and offers unprecedented WYSIWYG functionalities.
Visit: Aloha-Editor.org for more information

impress your audience with stunning visualization. save time & money with advanced web editing.

howto: click on text you want to edit. click outside the editable area to deactivate the edit mode and use the keybord navigation to switch slides.
known issue in this version: the cursor does not always move correctly -- but you can edit where you click.

you should try

# Aloha *

* just click to edit.

It's a presentation tool
inspired by the idea behind prezi.com
and based on the power of CSS3 transforms and transitions in modern browsers.

visualize your big thoughts

and tiny ideas.

edit everywhere!

by positioning, rotating and scaling them on an infinite canvas

the only limit is your imagination

want to know more?

fork me on github!

one more thing...

have you noticed it's in 3D*?

* beat that, prezi ;)

Use a spacebar or arrow keys to navigate